variable "manifest" {
  type    = string
  default = "manifest.json"
}

variable "borg_repo" {
  type    = string
  default = "rclone:pcloud:borg-backup"
}

variable "borg_passphrase" {
  type      = string
  sensitive = true
}

variable "patternsfile" {
  type    = string
  default = "/root/.config/borg/patterns.lst"
}

source "lxc" "borg-backup-build" {
  config_file         = "config/lxc-config"
  template_name       = "download"
  template_parameters = ["--dist", "Debian", "--release", "Bookworm", "--arch", "armv7l"]
}

build {
  sources = ["source.lxc.borg-backup-build"]

  provisioner "shell" {
    script = "scripts/timezone.sh"
  }

  provisioner "shell" {
    environment_vars = [
      "BORG_REPO=${var.borg_repo}",
      "BORG_PASSPHRASE=${var.borg_passphrase}",
      "PATTERNSFILE=${var.patternsfile}",
    ]
    script = "scripts/borg-backup.sh"
  }
}

packer {
  required_plugins {
    lxc = {
      version = ">= 1.0.2"
      source  = "github.com/hashicorp/lxc"
    }
  }
}
