variable "manifest" {
  type    = string
  default = "manifest.json"
}

variable "mysql_additional_hosts" {
  type    = string
  default = "\"127.0.0.1\" \"localhost\" \"localhost\""
}

variable "mysql_additional_passwords" {
  type      = string
  default   = "\"password1\" \"password2\" \"password3\""
  sensitive = true
}

variable "mysql_additional_users" {
  type    = string
  default = "\"user1\" \"user2\" \"user3\""
}

variable "mysql_bind" {
  type    = string
  default = "127.0.0.1"
}

variable "mysql_root_password" {
  type      = string
  default   = ""
  sensitive = true
}

source "lxc" "mariadb" {
  config_file         = "config/lxc-config"
  template_name       = "download"
  template_parameters = ["--dist", "Debian_by_maurer", "--release", "Bookworm", "--arch", "armv7l"]
}

build {
  sources = ["source.lxc.mariadb"]

  provisioner "shell" {
    script = "scripts/timezone.sh"
  }

  provisioner "shell" {
    environment_vars = [
      "MYSQL_BIND=${var.mysql_bind}",
      "MYSQL_ROOT_PASSWORD=${var.mysql_root_password}",
      "MYSQL_ADDITIONAL_USERS=${var.mysql_additional_users}",
      "MYSQL_ADDITIONAL_PASSWORDS=${var.mysql_additional_passwords}",
      "MYSQL_ADDITIONAL_HOSTS=${var.mysql_additional_hosts}"
    ]
    script = "scripts/mariadb.sh"
  }

  #provisioner "shell" {
  #  inline = ["mysql -e \"GRANT ALL PRIVILEGES on db1.* to 'user1'@'localhost';\""]
  #}

}

packer {
  required_plugins {
    lxc = {
      version = ">= 1.0.2"
      source  = "github.com/hashicorp/lxc"
    }
  }
}
