variable "manifest" {
  type    = string
  default = "manifest.json"
}

variable "minio_binary" {
  type    = string
  default = "./minio"
}

variable "minio_volumes" {
  type    = string
  default = "/mnt/data"
}

variable "minio_opts" {
  type    = string
  default = "--console-address :9001"
}

variable "minio_service_user" {
  type      = string
  default   = "minio-user"
}

variable "minio_service_group" {
  type      = string
  default   = "minio-user"
}

variable "minio_root_user" {
  type      = string
  default   = "root"
}

variable "minio_root_password" {
  type      = string
  sensitive = true
}

source "lxc" "minio" {
  config_file         = "config/lxc-config"
  template_name       = "download"
  template_parameters = ["--dist", "Debian_by_maurer", "--release", "Bookworm", "--arch", "armv7l"]
}

build {
  sources = ["source.lxc.minio"]

  provisioner "shell" {
    script = "scripts/timezone.sh"
  }

  provisioner "file" {
    source = "${var.minio_binary}"
    destination = "/usr/local/bin/minio"
  }

  provisioner "shell" {
    environment_vars = [
      "MINIO_ROOT_USER=${var.minio_root_user}",
      "MINIO_ROOT_PASSWORD=${var.minio_root_password}",
      "MINIO_VOLUMES=${var.minio_volumes}",
      "MINIO_OPTS=${var.minio_opts}",
      "MINIO_SERVICE_USER=${var.minio_service_user}",
      "MINIO_SERVICE_GROUP=${var.minio_service_group}"
    ]
    script = "scripts/minio.sh"
  }

}

packer {
  required_plugins {
    lxc = {
      version = ">= 1.0.2"
      source  = "github.com/hashicorp/lxc"
    }
  }
}
