#!/usr/bin/env bash

set -o errexit
set -o nounset
set -o xtrace

cd /root/

# Install borg backup prerequisites
# https://borgbackup.readthedocs.io/en/master/installation.html#debian-ubuntu
apt-get install -y python3 python3-dev python3-pip python3-virtualenv \
 libacl1-dev libacl1 \
 libssl-dev \
 liblz4-dev libzstd-dev libxxhash-dev \
 libffi-dev \
 build-essential \
 pkg-config python3-pkgconfig

# Install latest borg2 with pip
# https://borgbackup.readthedocs.io/en/master/installation.html#using-pip
virtualenv --python=python3 borg-env
source borg-env/bin/activate
pip install -U pip setuptools wheel
pip install pkgconfig
pip install borgbackup==2.0.0b14

# Symlink borg from venv to global path
ln -s /root/borg-env/bin/borg /usr/local/bin/borg

# Ensure the borg binary is in the path
cat <<'EOF' >> /root/.bashrc

PATH=$PATH:/usr/local/bin
EOF

# Configure borg repo on pcloud
mkdir -p /root/.config/borg

cat <<EOF > /root/.config/borg/config
BORG_REPO='$BORG_REPO'
BORG_PASSPHRASE='$BORG_PASSPHRASE'
PATTERNSFILE='$PATTERNSFILE'
EOF

# Check the encryption/hash bench with `borg benchmark cpu`
# You have to initialize the borg repo and rclone before first use
#  borg repo-create --encryption=repokey-chacha20-poly1305
#  rclone config

cat <<EOF > "$PATTERNSFILE"
# https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-patterns
# "sh:" pattern style, patternfiles use sh: by default
P sh
# A root path starts with the prefix R, followed by a path
R /host-nfs
R /host-srv
EOF

# Install systemd service unit
cat <<'EOF' > /etc/systemd/system/borg-backup.service
[Unit]
Description=Create a backup with borg

[Service]
Type=oneshot
EnvironmentFile=/root/.config/borg/config
ExecStart=/usr/local/bin/borg create -v --stats --compression lz4 {hostname}-{now:%%Y%%m%%dT%%H%%M} --patterns-from "$PATTERNSFILE" --exclude-caches --chunker-params fixed,4096
ExecStart=/usr/local/bin/borg prune -v --list --match-archives '{hostname}-*' --keep-daily=7 --keep-weekly=4 --keep-monthly=12

[Install]
WantedBy=default.target
EOF

# Install systemd timer
cat <<'EOF' > /etc/systemd/system/borg-backup.timer
[Unit]
Description=Create a backup with borg

[Timer]
Unit=borg-backup.service
OnCalendar=*-*-* 11:03:00

[Install]
WantedBy=timers.target
EOF

systemctl enable borg-backup.timer
systemctl start borg-backup.timer
