#!/usr/bin/env bash

set -o errexit
set -o nounset
set -o xtrace

# install mariadb server and tools
apt-get install -y mariadb-server mariadb-backup

# MySql secure install
# https://github.com/MariaDB/server/blob/main/scripts/mysql_secure_installation.sh
#
# Enter current password for root (enter for none)
# Switch to unix_socket authentication (y)
# New root password (twice)
# Remove anonymous users? (y)
# Disallow root login remotely? (y)
# Remove test database and access to it? (y)
# Reload privilege tables now? (y)

mariadb-secure-installation <<EOF

y
$MYSQL_ROOT_PASSWORD
$MYSQL_ROOT_PASSWORD
y
y
y
y
EOF

# configure .my.cnf for root
cat << EOF > /root/.my.cnf
[client]
user = root
password = $MYSQL_ROOT_PASSWORD
EOF

# add additional users
users=($MYSQL_ADDITIONAL_USERS)
hosts=($MYSQL_ADDITIONAL_HOSTS)
passwords=($MYSQL_ADDITIONAL_PASSWORDS)
no_users="${#users[@]}"
for ((i = 0 ; i < $no_users ; i++)); do
  mysql -e "CREATE USER '${users[$i]}'@'${hosts[$i]}' IDENTIFIED BY '${passwords[$i]}';"
done;

# bind
#IP_ETH0=$(ip route | grep eth0 | grep src | awk '{print $9}')
#HOSTNAME=LXCNAME works as well, but refers to the container that was built last (nslookup LXCNAME)
sed -i "s/\(bind.*\) 127.0.0.1/\1 $MYSQL_BIND/g" /etc/mysql/mariadb.conf.d/50-server.cnf
